# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SecretRule(object):
    """
    A rule that you can apply to a secret to enforce certain conditions on the secret's usage and management.
    """

    #: A constant which can be used with the rule_type property of a SecretRule.
    #: This constant has a value of "SECRET_EXPIRY_RULE"
    RULE_TYPE_SECRET_EXPIRY_RULE = "SECRET_EXPIRY_RULE"

    #: A constant which can be used with the rule_type property of a SecretRule.
    #: This constant has a value of "SECRET_REUSE_RULE"
    RULE_TYPE_SECRET_REUSE_RULE = "SECRET_REUSE_RULE"

    def __init__(self, **kwargs):
        """
        Initializes a new SecretRule object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.vault.models.SecretExpiryRule`
        * :class:`~oci.vault.models.SecretReuseRule`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param rule_type:
            The value to assign to the rule_type property of this SecretRule.
            Allowed values for this property are: "SECRET_EXPIRY_RULE", "SECRET_REUSE_RULE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type rule_type: str

        """
        self.swagger_types = {
            'rule_type': 'str'
        }

        self.attribute_map = {
            'rule_type': 'ruleType'
        }

        self._rule_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['ruleType']

        if type == 'SECRET_EXPIRY_RULE':
            return 'SecretExpiryRule'

        if type == 'SECRET_REUSE_RULE':
            return 'SecretReuseRule'
        else:
            return 'SecretRule'

    @property
    def rule_type(self):
        """
        **[Required]** Gets the rule_type of this SecretRule.
        The type of rule, which either controls when the secret contents expire or whether they can be reused.

        Allowed values for this property are: "SECRET_EXPIRY_RULE", "SECRET_REUSE_RULE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The rule_type of this SecretRule.
        :rtype: str
        """
        return self._rule_type

    @rule_type.setter
    def rule_type(self, rule_type):
        """
        Sets the rule_type of this SecretRule.
        The type of rule, which either controls when the secret contents expire or whether they can be reused.


        :param rule_type: The rule_type of this SecretRule.
        :type: str
        """
        allowed_values = ["SECRET_EXPIRY_RULE", "SECRET_REUSE_RULE"]
        if not value_allowed_none_or_none_sentinel(rule_type, allowed_values):
            rule_type = 'UNKNOWN_ENUM_VALUE'
        self._rule_type = rule_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SubscriptionMappingSummary(object):
    """
    Subscription mapping information.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SubscriptionMappingSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this SubscriptionMappingSummary.
        :type id: str

        :param subscription_id:
            The value to assign to the subscription_id property of this SubscriptionMappingSummary.
        :type subscription_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this SubscriptionMappingSummary.
        :type compartment_id: str

        :param is_explicitly_assigned:
            The value to assign to the is_explicitly_assigned property of this SubscriptionMappingSummary.
        :type is_explicitly_assigned: bool

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this SubscriptionMappingSummary.
        :type lifecycle_state: str

        :param time_terminated:
            The value to assign to the time_terminated property of this SubscriptionMappingSummary.
        :type time_terminated: datetime

        :param time_created:
            The value to assign to the time_created property of this SubscriptionMappingSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this SubscriptionMappingSummary.
        :type time_updated: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'subscription_id': 'str',
            'compartment_id': 'str',
            'is_explicitly_assigned': 'bool',
            'lifecycle_state': 'str',
            'time_terminated': 'datetime',
            'time_created': 'datetime',
            'time_updated': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'subscription_id': 'subscriptionId',
            'compartment_id': 'compartmentId',
            'is_explicitly_assigned': 'isExplicitlyAssigned',
            'lifecycle_state': 'lifecycleState',
            'time_terminated': 'timeTerminated',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated'
        }

        self._id = None
        self._subscription_id = None
        self._compartment_id = None
        self._is_explicitly_assigned = None
        self._lifecycle_state = None
        self._time_terminated = None
        self._time_created = None
        self._time_updated = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this SubscriptionMappingSummary.
        OCID of the mapping between subscription and compartment identified by the tenancy.


        :return: The id of this SubscriptionMappingSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SubscriptionMappingSummary.
        OCID of the mapping between subscription and compartment identified by the tenancy.


        :param id: The id of this SubscriptionMappingSummary.
        :type: str
        """
        self._id = id

    @property
    def subscription_id(self):
        """
        **[Required]** Gets the subscription_id of this SubscriptionMappingSummary.
        OCID of the subscription.


        :return: The subscription_id of this SubscriptionMappingSummary.
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """
        Sets the subscription_id of this SubscriptionMappingSummary.
        OCID of the subscription.


        :param subscription_id: The subscription_id of this SubscriptionMappingSummary.
        :type: str
        """
        self._subscription_id = subscription_id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this SubscriptionMappingSummary.
        OCID of the compartment. Always a tenancy OCID.


        :return: The compartment_id of this SubscriptionMappingSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this SubscriptionMappingSummary.
        OCID of the compartment. Always a tenancy OCID.


        :param compartment_id: The compartment_id of this SubscriptionMappingSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def is_explicitly_assigned(self):
        """
        **[Required]** Gets the is_explicitly_assigned of this SubscriptionMappingSummary.
        Denotes if the subscription is explicity assigned to the root compartment or tenancy.


        :return: The is_explicitly_assigned of this SubscriptionMappingSummary.
        :rtype: bool
        """
        return self._is_explicitly_assigned

    @is_explicitly_assigned.setter
    def is_explicitly_assigned(self, is_explicitly_assigned):
        """
        Sets the is_explicitly_assigned of this SubscriptionMappingSummary.
        Denotes if the subscription is explicity assigned to the root compartment or tenancy.


        :param is_explicitly_assigned: The is_explicitly_assigned of this SubscriptionMappingSummary.
        :type: bool
        """
        self._is_explicitly_assigned = is_explicitly_assigned

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this SubscriptionMappingSummary.
        Lifecycle state of the subscription mapping.


        :return: The lifecycle_state of this SubscriptionMappingSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this SubscriptionMappingSummary.
        Lifecycle state of the subscription mapping.


        :param lifecycle_state: The lifecycle_state of this SubscriptionMappingSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    @property
    def time_terminated(self):
        """
        Gets the time_terminated of this SubscriptionMappingSummary.
        Date-time when subscription mapping was terminated.


        :return: The time_terminated of this SubscriptionMappingSummary.
        :rtype: datetime
        """
        return self._time_terminated

    @time_terminated.setter
    def time_terminated(self, time_terminated):
        """
        Sets the time_terminated of this SubscriptionMappingSummary.
        Date-time when subscription mapping was terminated.


        :param time_terminated: The time_terminated of this SubscriptionMappingSummary.
        :type: datetime
        """
        self._time_terminated = time_terminated

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this SubscriptionMappingSummary.
        Date-time when subscription mapping was created.


        :return: The time_created of this SubscriptionMappingSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this SubscriptionMappingSummary.
        Date-time when subscription mapping was created.


        :param time_created: The time_created of this SubscriptionMappingSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this SubscriptionMappingSummary.
        Date-time when subscription mapping was updated.


        :return: The time_updated of this SubscriptionMappingSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this SubscriptionMappingSummary.
        Date-time when subscription mapping was updated.


        :param time_updated: The time_updated of this SubscriptionMappingSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TranscriptionTask(object):
    """
    Description of Transcription Task.
    """

    #: A constant which can be used with the lifecycle_state property of a TranscriptionTask.
    #: This constant has a value of "ACCEPTED"
    LIFECYCLE_STATE_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the lifecycle_state property of a TranscriptionTask.
    #: This constant has a value of "IN_PROGRESS"
    LIFECYCLE_STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a TranscriptionTask.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the lifecycle_state property of a TranscriptionTask.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a TranscriptionTask.
    #: This constant has a value of "CANCELED"
    LIFECYCLE_STATE_CANCELED = "CANCELED"

    def __init__(self, **kwargs):
        """
        Initializes a new TranscriptionTask object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this TranscriptionTask.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this TranscriptionTask.
        :type display_name: str

        :param time_started:
            The value to assign to the time_started property of this TranscriptionTask.
        :type time_started: datetime

        :param time_finished:
            The value to assign to the time_finished property of this TranscriptionTask.
        :type time_finished: datetime

        :param percent_complete:
            The value to assign to the percent_complete property of this TranscriptionTask.
        :type percent_complete: int

        :param ttl_in_days:
            The value to assign to the ttl_in_days property of this TranscriptionTask.
        :type ttl_in_days: int

        :param model_details:
            The value to assign to the model_details property of this TranscriptionTask.
        :type model_details: oci.ai_speech.models.TranscriptionModelDetails

        :param audio_format_details:
            The value to assign to the audio_format_details property of this TranscriptionTask.
        :type audio_format_details: oci.ai_speech.models.AudioFormatDetails

        :param file_size_in_bytes:
            The value to assign to the file_size_in_bytes property of this TranscriptionTask.
        :type file_size_in_bytes: int

        :param file_duration_in_seconds:
            The value to assign to the file_duration_in_seconds property of this TranscriptionTask.
        :type file_duration_in_seconds: int

        :param input_location:
            The value to assign to the input_location property of this TranscriptionTask.
        :type input_location: oci.ai_speech.models.ObjectLocation

        :param output_location:
            The value to assign to the output_location property of this TranscriptionTask.
        :type output_location: oci.ai_speech.models.ObjectLocation

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this TranscriptionTask.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this TranscriptionTask.
        :type lifecycle_details: str

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'time_started': 'datetime',
            'time_finished': 'datetime',
            'percent_complete': 'int',
            'ttl_in_days': 'int',
            'model_details': 'TranscriptionModelDetails',
            'audio_format_details': 'AudioFormatDetails',
            'file_size_in_bytes': 'int',
            'file_duration_in_seconds': 'int',
            'input_location': 'ObjectLocation',
            'output_location': 'ObjectLocation',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'time_started': 'timeStarted',
            'time_finished': 'timeFinished',
            'percent_complete': 'percentComplete',
            'ttl_in_days': 'ttlInDays',
            'model_details': 'modelDetails',
            'audio_format_details': 'audioFormatDetails',
            'file_size_in_bytes': 'fileSizeInBytes',
            'file_duration_in_seconds': 'fileDurationInSeconds',
            'input_location': 'inputLocation',
            'output_location': 'outputLocation',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails'
        }

        self._id = None
        self._display_name = None
        self._time_started = None
        self._time_finished = None
        self._percent_complete = None
        self._ttl_in_days = None
        self._model_details = None
        self._audio_format_details = None
        self._file_size_in_bytes = None
        self._file_duration_in_seconds = None
        self._input_location = None
        self._output_location = None
        self._lifecycle_state = None
        self._lifecycle_details = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this TranscriptionTask.
        The `OCID`__ of the task.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this TranscriptionTask.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TranscriptionTask.
        The `OCID`__ of the task.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this TranscriptionTask.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        Gets the display_name of this TranscriptionTask.
        A user-friendly display name for the task.


        :return: The display_name of this TranscriptionTask.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this TranscriptionTask.
        A user-friendly display name for the task.


        :param display_name: The display_name of this TranscriptionTask.
        :type: str
        """
        self._display_name = display_name

    @property
    def time_started(self):
        """
        Gets the time_started of this TranscriptionTask.
        Task started time.


        :return: The time_started of this TranscriptionTask.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this TranscriptionTask.
        Task started time.


        :param time_started: The time_started of this TranscriptionTask.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_finished(self):
        """
        Gets the time_finished of this TranscriptionTask.
        Task finished time.


        :return: The time_finished of this TranscriptionTask.
        :rtype: datetime
        """
        return self._time_finished

    @time_finished.setter
    def time_finished(self, time_finished):
        """
        Sets the time_finished of this TranscriptionTask.
        Task finished time.


        :param time_finished: The time_finished of this TranscriptionTask.
        :type: datetime
        """
        self._time_finished = time_finished

    @property
    def percent_complete(self):
        """
        Gets the percent_complete of this TranscriptionTask.
        How much progress the operation has made, vs the total amount of work that must be performed.


        :return: The percent_complete of this TranscriptionTask.
        :rtype: int
        """
        return self._percent_complete

    @percent_complete.setter
    def percent_complete(self, percent_complete):
        """
        Sets the percent_complete of this TranscriptionTask.
        How much progress the operation has made, vs the total amount of work that must be performed.


        :param percent_complete: The percent_complete of this TranscriptionTask.
        :type: int
        """
        self._percent_complete = percent_complete

    @property
    def ttl_in_days(self):
        """
        Gets the ttl_in_days of this TranscriptionTask.
        Time to live duration in days for tasks. Task will be available till max 90 days.


        :return: The ttl_in_days of this TranscriptionTask.
        :rtype: int
        """
        return self._ttl_in_days

    @ttl_in_days.setter
    def ttl_in_days(self, ttl_in_days):
        """
        Sets the ttl_in_days of this TranscriptionTask.
        Time to live duration in days for tasks. Task will be available till max 90 days.


        :param ttl_in_days: The ttl_in_days of this TranscriptionTask.
        :type: int
        """
        self._ttl_in_days = ttl_in_days

    @property
    def model_details(self):
        """
        Gets the model_details of this TranscriptionTask.

        :return: The model_details of this TranscriptionTask.
        :rtype: oci.ai_speech.models.TranscriptionModelDetails
        """
        return self._model_details

    @model_details.setter
    def model_details(self, model_details):
        """
        Sets the model_details of this TranscriptionTask.

        :param model_details: The model_details of this TranscriptionTask.
        :type: oci.ai_speech.models.TranscriptionModelDetails
        """
        self._model_details = model_details

    @property
    def audio_format_details(self):
        """
        Gets the audio_format_details of this TranscriptionTask.

        :return: The audio_format_details of this TranscriptionTask.
        :rtype: oci.ai_speech.models.AudioFormatDetails
        """
        return self._audio_format_details

    @audio_format_details.setter
    def audio_format_details(self, audio_format_details):
        """
        Sets the audio_format_details of this TranscriptionTask.

        :param audio_format_details: The audio_format_details of this TranscriptionTask.
        :type: oci.ai_speech.models.AudioFormatDetails
        """
        self._audio_format_details = audio_format_details

    @property
    def file_size_in_bytes(self):
        """
        Gets the file_size_in_bytes of this TranscriptionTask.
        Size of input file in Bytes.


        :return: The file_size_in_bytes of this TranscriptionTask.
        :rtype: int
        """
        return self._file_size_in_bytes

    @file_size_in_bytes.setter
    def file_size_in_bytes(self, file_size_in_bytes):
        """
        Sets the file_size_in_bytes of this TranscriptionTask.
        Size of input file in Bytes.


        :param file_size_in_bytes: The file_size_in_bytes of this TranscriptionTask.
        :type: int
        """
        self._file_size_in_bytes = file_size_in_bytes

    @property
    def file_duration_in_seconds(self):
        """
        Gets the file_duration_in_seconds of this TranscriptionTask.
        Duration of input file in Seconds.


        :return: The file_duration_in_seconds of this TranscriptionTask.
        :rtype: int
        """
        return self._file_duration_in_seconds

    @file_duration_in_seconds.setter
    def file_duration_in_seconds(self, file_duration_in_seconds):
        """
        Sets the file_duration_in_seconds of this TranscriptionTask.
        Duration of input file in Seconds.


        :param file_duration_in_seconds: The file_duration_in_seconds of this TranscriptionTask.
        :type: int
        """
        self._file_duration_in_seconds = file_duration_in_seconds

    @property
    def input_location(self):
        """
        Gets the input_location of this TranscriptionTask.

        :return: The input_location of this TranscriptionTask.
        :rtype: oci.ai_speech.models.ObjectLocation
        """
        return self._input_location

    @input_location.setter
    def input_location(self, input_location):
        """
        Sets the input_location of this TranscriptionTask.

        :param input_location: The input_location of this TranscriptionTask.
        :type: oci.ai_speech.models.ObjectLocation
        """
        self._input_location = input_location

    @property
    def output_location(self):
        """
        Gets the output_location of this TranscriptionTask.

        :return: The output_location of this TranscriptionTask.
        :rtype: oci.ai_speech.models.ObjectLocation
        """
        return self._output_location

    @output_location.setter
    def output_location(self, output_location):
        """
        Sets the output_location of this TranscriptionTask.

        :param output_location: The output_location of this TranscriptionTask.
        :type: oci.ai_speech.models.ObjectLocation
        """
        self._output_location = output_location

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this TranscriptionTask.
        The current state of the Task.

        Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this TranscriptionTask.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this TranscriptionTask.
        The current state of the Task.


        :param lifecycle_state: The lifecycle_state of this TranscriptionTask.
        :type: str
        """
        allowed_values = ["ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", "CANCELED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this TranscriptionTask.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :return: The lifecycle_details of this TranscriptionTask.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this TranscriptionTask.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :param lifecycle_details: The lifecycle_details of this TranscriptionTask.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RefreshRequest(object):
    """
    RefreshRequest model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RefreshRequest object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param current_token:
            The value to assign to the current_token property of this RefreshRequest.
        :type current_token: str

        :param new_public_key:
            The value to assign to the new_public_key property of this RefreshRequest.
        :type new_public_key: str

        """
        self.swagger_types = {
            'current_token': 'str',
            'new_public_key': 'str'
        }

        self.attribute_map = {
            'current_token': 'currentToken',
            'new_public_key': 'newPublicKey'
        }

        self._current_token = None
        self._new_public_key = None

    @property
    def current_token(self):
        """
        **[Required]** Gets the current_token of this RefreshRequest.
        The current security token that is to be renewed.


        :return: The current_token of this RefreshRequest.
        :rtype: str
        """
        return self._current_token

    @current_token.setter
    def current_token(self, current_token):
        """
        Sets the current_token of this RefreshRequest.
        The current security token that is to be renewed.


        :param current_token: The current_token of this RefreshRequest.
        :type: str
        """
        self._current_token = current_token

    @property
    def new_public_key(self):
        """
        Gets the new_public_key of this RefreshRequest.
        An optional new public for the new token. If not supplied, currentToken's public key will be used.


        :return: The new_public_key of this RefreshRequest.
        :rtype: str
        """
        return self._new_public_key

    @new_public_key.setter
    def new_public_key(self, new_public_key):
        """
        Sets the new_public_key of this RefreshRequest.
        An optional new public for the new token. If not supplied, currentToken's public key will be used.


        :param new_public_key: The new_public_key of this RefreshRequest.
        :type: str
        """
        self._new_public_key = new_public_key

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ByoipRangeVcnIpv6AllocationSummary(object):
    """
    A summary of IPv6 CIDR block subranges currently allocated to a VCN.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ByoipRangeVcnIpv6AllocationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param byoip_range_id:
            The value to assign to the byoip_range_id property of this ByoipRangeVcnIpv6AllocationSummary.
        :type byoip_range_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ByoipRangeVcnIpv6AllocationSummary.
        :type compartment_id: str

        :param ipv6_cidr_block:
            The value to assign to the ipv6_cidr_block property of this ByoipRangeVcnIpv6AllocationSummary.
        :type ipv6_cidr_block: str

        :param vcn_id:
            The value to assign to the vcn_id property of this ByoipRangeVcnIpv6AllocationSummary.
        :type vcn_id: str

        """
        self.swagger_types = {
            'byoip_range_id': 'str',
            'compartment_id': 'str',
            'ipv6_cidr_block': 'str',
            'vcn_id': 'str'
        }

        self.attribute_map = {
            'byoip_range_id': 'byoipRangeId',
            'compartment_id': 'compartmentId',
            'ipv6_cidr_block': 'ipv6CidrBlock',
            'vcn_id': 'vcnId'
        }

        self._byoip_range_id = None
        self._compartment_id = None
        self._ipv6_cidr_block = None
        self._vcn_id = None

    @property
    def byoip_range_id(self):
        """
        Gets the byoip_range_id of this ByoipRangeVcnIpv6AllocationSummary.
        The `OCID`__ of the `ByoipRange` resource to which the CIDR block belongs.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The byoip_range_id of this ByoipRangeVcnIpv6AllocationSummary.
        :rtype: str
        """
        return self._byoip_range_id

    @byoip_range_id.setter
    def byoip_range_id(self, byoip_range_id):
        """
        Sets the byoip_range_id of this ByoipRangeVcnIpv6AllocationSummary.
        The `OCID`__ of the `ByoipRange` resource to which the CIDR block belongs.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param byoip_range_id: The byoip_range_id of this ByoipRangeVcnIpv6AllocationSummary.
        :type: str
        """
        self._byoip_range_id = byoip_range_id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this ByoipRangeVcnIpv6AllocationSummary.
        The `OCID`__ of the compartment containing the `ByoipRange`.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this ByoipRangeVcnIpv6AllocationSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ByoipRangeVcnIpv6AllocationSummary.
        The `OCID`__ of the compartment containing the `ByoipRange`.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this ByoipRangeVcnIpv6AllocationSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def ipv6_cidr_block(self):
        """
        Gets the ipv6_cidr_block of this ByoipRangeVcnIpv6AllocationSummary.
        The BYOIPv6 CIDR block range or subrange allocated to a VCN. This could be all or part of a BYOIPv6 CIDR block.
        Each VCN allocation must be /64 or larger.


        :return: The ipv6_cidr_block of this ByoipRangeVcnIpv6AllocationSummary.
        :rtype: str
        """
        return self._ipv6_cidr_block

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, ipv6_cidr_block):
        """
        Sets the ipv6_cidr_block of this ByoipRangeVcnIpv6AllocationSummary.
        The BYOIPv6 CIDR block range or subrange allocated to a VCN. This could be all or part of a BYOIPv6 CIDR block.
        Each VCN allocation must be /64 or larger.


        :param ipv6_cidr_block: The ipv6_cidr_block of this ByoipRangeVcnIpv6AllocationSummary.
        :type: str
        """
        self._ipv6_cidr_block = ipv6_cidr_block

    @property
    def vcn_id(self):
        """
        Gets the vcn_id of this ByoipRangeVcnIpv6AllocationSummary.
        The `OCID`__ of the `Vcn` resource to which the ByoipRange belongs.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The vcn_id of this ByoipRangeVcnIpv6AllocationSummary.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this ByoipRangeVcnIpv6AllocationSummary.
        The `OCID`__ of the `Vcn` resource to which the ByoipRange belongs.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param vcn_id: The vcn_id of this ByoipRangeVcnIpv6AllocationSummary.
        :type: str
        """
        self._vcn_id = vcn_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class IndicatorCountDimensions(object):
    """
    Dimensions characterizing the group
    """

    #: A constant which can be used with the type property of a IndicatorCountDimensions.
    #: This constant has a value of "DOMAIN_NAME"
    TYPE_DOMAIN_NAME = "DOMAIN_NAME"

    #: A constant which can be used with the type property of a IndicatorCountDimensions.
    #: This constant has a value of "FILE_NAME"
    TYPE_FILE_NAME = "FILE_NAME"

    #: A constant which can be used with the type property of a IndicatorCountDimensions.
    #: This constant has a value of "MD5_HASH"
    TYPE_MD5_HASH = "MD5_HASH"

    #: A constant which can be used with the type property of a IndicatorCountDimensions.
    #: This constant has a value of "SHA1_HASH"
    TYPE_SHA1_HASH = "SHA1_HASH"

    #: A constant which can be used with the type property of a IndicatorCountDimensions.
    #: This constant has a value of "SHA256_HASH"
    TYPE_SHA256_HASH = "SHA256_HASH"

    #: A constant which can be used with the type property of a IndicatorCountDimensions.
    #: This constant has a value of "IP_ADDRESS"
    TYPE_IP_ADDRESS = "IP_ADDRESS"

    #: A constant which can be used with the type property of a IndicatorCountDimensions.
    #: This constant has a value of "URL"
    TYPE_URL = "URL"

    def __init__(self, **kwargs):
        """
        Initializes a new IndicatorCountDimensions object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this IndicatorCountDimensions.
        :type compartment_id: str

        :param type:
            The value to assign to the type property of this IndicatorCountDimensions.
            Allowed values for this property are: "DOMAIN_NAME", "FILE_NAME", "MD5_HASH", "SHA1_HASH", "SHA256_HASH", "IP_ADDRESS", "URL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'type': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'type': 'type'
        }

        self._compartment_id = None
        self._type = None

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this IndicatorCountDimensions.
        Compartment Identifier


        :return: The compartment_id of this IndicatorCountDimensions.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this IndicatorCountDimensions.
        Compartment Identifier


        :param compartment_id: The compartment_id of this IndicatorCountDimensions.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def type(self):
        """
        Gets the type of this IndicatorCountDimensions.
        The indicator type that corresponds to the count.

        Allowed values for this property are: "DOMAIN_NAME", "FILE_NAME", "MD5_HASH", "SHA1_HASH", "SHA256_HASH", "IP_ADDRESS", "URL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this IndicatorCountDimensions.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this IndicatorCountDimensions.
        The indicator type that corresponds to the count.


        :param type: The type of this IndicatorCountDimensions.
        :type: str
        """
        allowed_values = ["DOMAIN_NAME", "FILE_NAME", "MD5_HASH", "SHA1_HASH", "SHA256_HASH", "IP_ADDRESS", "URL"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .access_policy_target import AccessPolicyTarget
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VirtualServiceAccessPolicyTarget(AccessPolicyTarget):
    """
    Virtual service target which communicates with other virtual services in a mesh.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VirtualServiceAccessPolicyTarget object with values from keyword arguments. The default value of the :py:attr:`~oci.service_mesh.models.VirtualServiceAccessPolicyTarget.type` attribute
        of this class is ``VIRTUAL_SERVICE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this VirtualServiceAccessPolicyTarget.
            Allowed values for this property are: "ALL_VIRTUAL_SERVICES", "VIRTUAL_SERVICE", "EXTERNAL_SERVICE", "INGRESS_GATEWAY"
        :type type: str

        :param virtual_service_id:
            The value to assign to the virtual_service_id property of this VirtualServiceAccessPolicyTarget.
        :type virtual_service_id: str

        """
        self.swagger_types = {
            'type': 'str',
            'virtual_service_id': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'virtual_service_id': 'virtualServiceId'
        }

        self._type = None
        self._virtual_service_id = None
        self._type = 'VIRTUAL_SERVICE'

    @property
    def virtual_service_id(self):
        """
        **[Required]** Gets the virtual_service_id of this VirtualServiceAccessPolicyTarget.
        The OCID of the virtual service resource.


        :return: The virtual_service_id of this VirtualServiceAccessPolicyTarget.
        :rtype: str
        """
        return self._virtual_service_id

    @virtual_service_id.setter
    def virtual_service_id(self, virtual_service_id):
        """
        Sets the virtual_service_id of this VirtualServiceAccessPolicyTarget.
        The OCID of the virtual service resource.


        :param virtual_service_id: The virtual_service_id of this VirtualServiceAccessPolicyTarget.
        :type: str
        """
        self._virtual_service_id = virtual_service_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RemoveDatasetLabelsDetails(object):
    """
    Removes a subset of Labels from the Dataset's LabelSet.  This LabelSet will be subtracted from the current Dataset's LabelSet. Requests\u00A0with non-existent Labels will be rejected.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RemoveDatasetLabelsDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param label_set:
            The value to assign to the label_set property of this RemoveDatasetLabelsDetails.
        :type label_set: oci.data_labeling_service.models.LabelSet

        """
        self.swagger_types = {
            'label_set': 'LabelSet'
        }

        self.attribute_map = {
            'label_set': 'labelSet'
        }

        self._label_set = None

    @property
    def label_set(self):
        """
        Gets the label_set of this RemoveDatasetLabelsDetails.

        :return: The label_set of this RemoveDatasetLabelsDetails.
        :rtype: oci.data_labeling_service.models.LabelSet
        """
        return self._label_set

    @label_set.setter
    def label_set(self, label_set):
        """
        Sets the label_set of this RemoveDatasetLabelsDetails.

        :param label_set: The label_set of this RemoveDatasetLabelsDetails.
        :type: oci.data_labeling_service.models.LabelSet
        """
        self._label_set = label_set

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .allowed_regions_template import AllowedRegionsTemplate
from .association import Association
from .base_tag_definition_validator import BaseTagDefinitionValidator
from .create_governance_rule_details import CreateGovernanceRuleDetails
from .create_inclusion_criterion_details import CreateInclusionCriterionDetails
from .default_tag_definition_validator import DefaultTagDefinitionValidator
from .enforced_governance_rule import EnforcedGovernanceRule
from .enforced_governance_rule_collection import EnforcedGovernanceRuleCollection
from .enforced_governance_rule_summary import EnforcedGovernanceRuleSummary
from .enum_tag_definition_validator import EnumTagDefinitionValidator
from .governance_rule import GovernanceRule
from .governance_rule_collection import GovernanceRuleCollection
from .governance_rule_summary import GovernanceRuleSummary
from .inclusion_criterion import InclusionCriterion
from .inclusion_criterion_collection import InclusionCriterionCollection
from .inclusion_criterion_summary import InclusionCriterionSummary
from .quota_template import QuotaTemplate
from .tag import Tag
from .tag_default import TagDefault
from .tag_template import TagTemplate
from .template import Template
from .tenancy_association import TenancyAssociation
from .tenancy_attachment import TenancyAttachment
from .tenancy_attachment_collection import TenancyAttachmentCollection
from .tenancy_attachment_summary import TenancyAttachmentSummary
from .update_governance_rule_details import UpdateGovernanceRuleDetails
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary
from .work_request_summary_collection import WorkRequestSummaryCollection

# Maps type names to classes for governance_rules_control_plane services.
governance_rules_control_plane_type_mapping = {
    "AllowedRegionsTemplate": AllowedRegionsTemplate,
    "Association": Association,
    "BaseTagDefinitionValidator": BaseTagDefinitionValidator,
    "CreateGovernanceRuleDetails": CreateGovernanceRuleDetails,
    "CreateInclusionCriterionDetails": CreateInclusionCriterionDetails,
    "DefaultTagDefinitionValidator": DefaultTagDefinitionValidator,
    "EnforcedGovernanceRule": EnforcedGovernanceRule,
    "EnforcedGovernanceRuleCollection": EnforcedGovernanceRuleCollection,
    "EnforcedGovernanceRuleSummary": EnforcedGovernanceRuleSummary,
    "EnumTagDefinitionValidator": EnumTagDefinitionValidator,
    "GovernanceRule": GovernanceRule,
    "GovernanceRuleCollection": GovernanceRuleCollection,
    "GovernanceRuleSummary": GovernanceRuleSummary,
    "InclusionCriterion": InclusionCriterion,
    "InclusionCriterionCollection": InclusionCriterionCollection,
    "InclusionCriterionSummary": InclusionCriterionSummary,
    "QuotaTemplate": QuotaTemplate,
    "Tag": Tag,
    "TagDefault": TagDefault,
    "TagTemplate": TagTemplate,
    "Template": Template,
    "TenancyAssociation": TenancyAssociation,
    "TenancyAttachment": TenancyAttachment,
    "TenancyAttachmentCollection": TenancyAttachmentCollection,
    "TenancyAttachmentSummary": TenancyAttachmentSummary,
    "UpdateGovernanceRuleDetails": UpdateGovernanceRuleDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary,
    "WorkRequestSummaryCollection": WorkRequestSummaryCollection
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_dashboard_details import UpdateDashboardDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateV1DashboardDetails(UpdateDashboardDetails):
    """
    Details for updating a version 1 dashboard.
    The interpretation of the `config` and `widgets` fields depends on the runtime behavior of the Oracle Cloud Infrastructure Console.
    The sum of the `config` and `widget` fields JSON text representation cannot exceed 200 KB.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateV1DashboardDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.dashboard_service.models.UpdateV1DashboardDetails.schema_version` attribute
        of this class is ``V1`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateV1DashboardDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this UpdateV1DashboardDetails.
        :type description: str

        :param schema_version:
            The value to assign to the schema_version property of this UpdateV1DashboardDetails.
        :type schema_version: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateV1DashboardDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateV1DashboardDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param config:
            The value to assign to the config property of this UpdateV1DashboardDetails.
        :type config: object

        :param widgets:
            The value to assign to the widgets property of this UpdateV1DashboardDetails.
        :type widgets: list[object]

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'schema_version': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'config': 'object',
            'widgets': 'list[object]'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'schema_version': 'schemaVersion',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'config': 'config',
            'widgets': 'widgets'
        }

        self._display_name = None
        self._description = None
        self._schema_version = None
        self._freeform_tags = None
        self._defined_tags = None
        self._config = None
        self._widgets = None
        self._schema_version = 'V1'

    @property
    def config(self):
        """
        Gets the config of this UpdateV1DashboardDetails.
        The layout and widget placement for the dashboard.


        :return: The config of this UpdateV1DashboardDetails.
        :rtype: object
        """
        return self._config

    @config.setter
    def config(self, config):
        """
        Sets the config of this UpdateV1DashboardDetails.
        The layout and widget placement for the dashboard.


        :param config: The config of this UpdateV1DashboardDetails.
        :type: object
        """
        self._config = config

    @property
    def widgets(self):
        """
        Gets the widgets of this UpdateV1DashboardDetails.
        The basic visualization building blocks of a dashboard.


        :return: The widgets of this UpdateV1DashboardDetails.
        :rtype: list[object]
        """
        return self._widgets

    @widgets.setter
    def widgets(self, widgets):
        """
        Sets the widgets of this UpdateV1DashboardDetails.
        The basic visualization building blocks of a dashboard.


        :param widgets: The widgets of this UpdateV1DashboardDetails.
        :type: list[object]
        """
        self._widgets = widgets

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TimeAndHorizontalScalingConfig(object):
    """
    Time of day and horizontal scaling configuration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TimeAndHorizontalScalingConfig object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_recurrence:
            The value to assign to the time_recurrence property of this TimeAndHorizontalScalingConfig.
        :type time_recurrence: str

        :param target_node_count:
            The value to assign to the target_node_count property of this TimeAndHorizontalScalingConfig.
        :type target_node_count: int

        """
        self.swagger_types = {
            'time_recurrence': 'str',
            'target_node_count': 'int'
        }

        self.attribute_map = {
            'time_recurrence': 'timeRecurrence',
            'target_node_count': 'targetNodeCount'
        }

        self._time_recurrence = None
        self._target_node_count = None

    @property
    def time_recurrence(self):
        """
        Gets the time_recurrence of this TimeAndHorizontalScalingConfig.
        Day/time recurrence (specified following RFC 5545) at which to trigger autoscaling action. Currently only WEEKLY frequency is supported. Days of the week are specified using BYDAY field. Time of the day is specified using BYHOUR and BYMINUTE fields. Other fields are not supported.


        :return: The time_recurrence of this TimeAndHorizontalScalingConfig.
        :rtype: str
        """
        return self._time_recurrence

    @time_recurrence.setter
    def time_recurrence(self, time_recurrence):
        """
        Sets the time_recurrence of this TimeAndHorizontalScalingConfig.
        Day/time recurrence (specified following RFC 5545) at which to trigger autoscaling action. Currently only WEEKLY frequency is supported. Days of the week are specified using BYDAY field. Time of the day is specified using BYHOUR and BYMINUTE fields. Other fields are not supported.


        :param time_recurrence: The time_recurrence of this TimeAndHorizontalScalingConfig.
        :type: str
        """
        self._time_recurrence = time_recurrence

    @property
    def target_node_count(self):
        """
        Gets the target_node_count of this TimeAndHorizontalScalingConfig.
        This value is the desired number of nodes in the cluster.


        :return: The target_node_count of this TimeAndHorizontalScalingConfig.
        :rtype: int
        """
        return self._target_node_count

    @target_node_count.setter
    def target_node_count(self, target_node_count):
        """
        Sets the target_node_count of this TimeAndHorizontalScalingConfig.
        This value is the desired number of nodes in the cluster.


        :param target_node_count: The target_node_count of this TimeAndHorizontalScalingConfig.
        :type: int
        """
        self._target_node_count = target_node_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2018, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Copyright 2018 Kenneth Reitz

# -*- coding: utf-8 -*-

"""
requests.hooks
~~~~~~~~~~~~~~

This module provides the capabilities for the Requests hooks system.

Available hooks:

``response``:
    The response generated from a Request.
"""
HOOKS = ['response']


def default_hooks():
    return {event: [] for event in HOOKS}

# TODO: response is the only one


def dispatch_hook(key, hooks, hook_data, **kwargs):
    """Dispatches a hook dictionary on a given piece of data."""
    hooks = hooks or {}
    hooks = hooks.get(key)
    if hooks:
        if hasattr(hooks, '__call__'):
            hooks = [hooks]
        for hook in hooks:
            _hook_data = hook(hook_data, **kwargs)
            if _hook_data is not None:
                hook_data = _hook_data
    return hook_data



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MonitoringSourceSelectedNamespace(object):
    """
    A metric namespace for the compartment-specific list.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MonitoringSourceSelectedNamespace object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param namespace:
            The value to assign to the namespace property of this MonitoringSourceSelectedNamespace.
        :type namespace: str

        :param metrics:
            The value to assign to the metrics property of this MonitoringSourceSelectedNamespace.
        :type metrics: oci.sch.models.MonitoringSourceMetricDetails

        """
        self.swagger_types = {
            'namespace': 'str',
            'metrics': 'MonitoringSourceMetricDetails'
        }

        self.attribute_map = {
            'namespace': 'namespace',
            'metrics': 'metrics'
        }

        self._namespace = None
        self._metrics = None

    @property
    def namespace(self):
        """
        **[Required]** Gets the namespace of this MonitoringSourceSelectedNamespace.
        The source service or application to use when querying for metric data points. Must begin with `oci_`.

        Example: `oci_computeagent`


        :return: The namespace of this MonitoringSourceSelectedNamespace.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this MonitoringSourceSelectedNamespace.
        The source service or application to use when querying for metric data points. Must begin with `oci_`.

        Example: `oci_computeagent`


        :param namespace: The namespace of this MonitoringSourceSelectedNamespace.
        :type: str
        """
        self._namespace = namespace

    @property
    def metrics(self):
        """
        **[Required]** Gets the metrics of this MonitoringSourceSelectedNamespace.

        :return: The metrics of this MonitoringSourceSelectedNamespace.
        :rtype: oci.sch.models.MonitoringSourceMetricDetails
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """
        Sets the metrics of this MonitoringSourceSelectedNamespace.

        :param metrics: The metrics of this MonitoringSourceSelectedNamespace.
        :type: oci.sch.models.MonitoringSourceMetricDetails
        """
        self._metrics = metrics

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DiscoveryJob(object):
    """
    A data discovery job. It helps track job's metadata as well as result statistics.
    """

    #: A constant which can be used with the discovery_type property of a DiscoveryJob.
    #: This constant has a value of "ALL"
    DISCOVERY_TYPE_ALL = "ALL"

    #: A constant which can be used with the discovery_type property of a DiscoveryJob.
    #: This constant has a value of "NEW"
    DISCOVERY_TYPE_NEW = "NEW"

    #: A constant which can be used with the discovery_type property of a DiscoveryJob.
    #: This constant has a value of "MODIFIED"
    DISCOVERY_TYPE_MODIFIED = "MODIFIED"

    #: A constant which can be used with the discovery_type property of a DiscoveryJob.
    #: This constant has a value of "DELETED"
    DISCOVERY_TYPE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a DiscoveryJob.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a DiscoveryJob.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DiscoveryJob.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a DiscoveryJob.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a DiscoveryJob.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a DiscoveryJob.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new DiscoveryJob object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DiscoveryJob.
        :type id: str

        :param discovery_type:
            The value to assign to the discovery_type property of this DiscoveryJob.
            Allowed values for this property are: "ALL", "NEW", "MODIFIED", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type discovery_type: str

        :param display_name:
            The value to assign to the display_name property of this DiscoveryJob.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DiscoveryJob.
        :type compartment_id: str

        :param time_started:
            The value to assign to the time_started property of this DiscoveryJob.
        :type time_started: datetime

        :param time_finished:
            The value to assign to the time_finished property of this DiscoveryJob.
        :type time_finished: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DiscoveryJob.
            Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param sensitive_data_model_id:
            The value to assign to the sensitive_data_model_id property of this DiscoveryJob.
        :type sensitive_data_model_id: str

        :param target_id:
            The value to assign to the target_id property of this DiscoveryJob.
        :type target_id: str

        :param schemas_for_discovery:
            The value to assign to the schemas_for_discovery property of this DiscoveryJob.
        :type schemas_for_discovery: list[str]

        :param sensitive_type_ids_for_discovery:
            The value to assign to the sensitive_type_ids_for_discovery property of this DiscoveryJob.
        :type sensitive_type_ids_for_discovery: list[str]

        :param is_sample_data_collection_enabled:
            The value to assign to the is_sample_data_collection_enabled property of this DiscoveryJob.
        :type is_sample_data_collection_enabled: bool

        :param is_app_defined_relation_discovery_enabled:
            The value to assign to the is_app_defined_relation_discovery_enabled property of this DiscoveryJob.
        :type is_app_defined_relation_discovery_enabled: bool

        :param is_include_all_schemas:
            The value to assign to the is_include_all_schemas property of this DiscoveryJob.
        :type is_include_all_schemas: bool

        :param is_include_all_sensitive_types:
            The value to assign to the is_include_all_sensitive_types property of this DiscoveryJob.
        :type is_include_all_sensitive_types: bool

        :param total_schemas_scanned:
            The value to assign to the total_schemas_scanned property of this DiscoveryJob.
        :type total_schemas_scanned: int

        :param total_objects_scanned:
            The value to assign to the total_objects_scanned property of this DiscoveryJob.
        :type total_objects_scanned: int

        :param total_columns_scanned:
            The value to assign to the total_columns_scanned property of this DiscoveryJob.
        :type total_columns_scanned: int

        :param total_new_sensitive_columns:
            The value to assign to the total_new_sensitive_columns property of this DiscoveryJob.
        :type total_new_sensitive_columns: int

        :param total_modified_sensitive_columns:
            The value to assign to the total_modified_sensitive_columns property of this DiscoveryJob.
        :type total_modified_sensitive_columns: int

        :param total_deleted_sensitive_columns:
            The value to assign to the total_deleted_sensitive_columns property of this DiscoveryJob.
        :type total_deleted_sensitive_columns: int

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DiscoveryJob.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DiscoveryJob.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this DiscoveryJob.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'discovery_type': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'time_started': 'datetime',
            'time_finished': 'datetime',
            'lifecycle_state': 'str',
            'sensitive_data_model_id': 'str',
            'target_id': 'str',
            'schemas_for_discovery': 'list[str]',
            'sensitive_type_ids_for_discovery': 'list[str]',
            'is_sample_data_collection_enabled': 'bool',
            'is_app_defined_relation_discovery_enabled': 'bool',
            'is_include_all_schemas': 'bool',
            'is_include_all_sensitive_types': 'bool',
            'total_schemas_scanned': 'int',
            'total_objects_scanned': 'int',
            'total_columns_scanned': 'int',
            'total_new_sensitive_columns': 'int',
            'total_modified_sensitive_columns': 'int',
            'total_deleted_sensitive_columns': 'int',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'discovery_type': 'discoveryType',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'time_started': 'timeStarted',
            'time_finished': 'timeFinished',
            'lifecycle_state': 'lifecycleState',
            'sensitive_data_model_id': 'sensitiveDataModelId',
            'target_id': 'targetId',
            'schemas_for_discovery': 'schemasForDiscovery',
            'sensitive_type_ids_for_discovery': 'sensitiveTypeIdsForDiscovery',
            'is_sample_data_collection_enabled': 'isSampleDataCollectionEnabled',
            'is_app_defined_relation_discovery_enabled': 'isAppDefinedRelationDiscoveryEnabled',
            'is_include_all_schemas': 'isIncludeAllSchemas',
            'is_include_all_sensitive_types': 'isIncludeAllSensitiveTypes',
            'total_schemas_scanned': 'totalSchemasScanned',
            'total_objects_scanned': 'totalObjectsScanned',
            'total_columns_scanned': 'totalColumnsScanned',
            'total_new_sensitive_columns': 'totalNewSensitiveColumns',
            'total_modified_sensitive_columns': 'totalModifiedSensitiveColumns',
            'total_deleted_sensitive_columns': 'totalDeletedSensitiveColumns',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._discovery_type = None
        self._display_name = None
        self._compartment_id = None
        self._time_started = None
        self._time_finished = None
        self._lifecycle_state = None
        self._sensitive_data_model_id = None
        self._target_id = None
        self._schemas_for_discovery = None
        self._sensitive_type_ids_for_discovery = None
        self._is_sample_data_collection_enabled = None
        self._is_app_defined_relation_discovery_enabled = None
        self._is_include_all_schemas = None
        self._is_include_all_sensitive_types = None
        self._total_schemas_scanned = None
        self._total_objects_scanned = None
        self._total_columns_scanned = None
        self._total_new_sensitive_columns = None
        self._total_modified_sensitive_columns = None
        self._total_deleted_sensitive_columns = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DiscoveryJob.
        The OCID of the discovery job.


        :return: The id of this DiscoveryJob.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DiscoveryJob.
        The OCID of the discovery job.


        :param id: The id of this DiscoveryJob.
        :type: str
        """
        self._id = id

    @property
    def discovery_type(self):
        """
        **[Required]** Gets the discovery_type of this DiscoveryJob.
        The type of the discovery job. It defines the job's scope.
        NEW identifies new sensitive columns in the target database that are not in the sensitive data model.
        DELETED identifies columns that are present in the sensitive data model but have been deleted from the target database.
        MODIFIED identifies columns that are present in the target database as well as the sensitive data model but some of their attributes have been modified.
        ALL covers all the above three scenarios and reports new, deleted and modified columns.

        Allowed values for this property are: "ALL", "NEW", "MODIFIED", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The discovery_type of this DiscoveryJob.
        :rtype: str
        """
        return self._discovery_type

    @discovery_type.setter
    def discovery_type(self, discovery_type):
        """
        Sets the discovery_type of this DiscoveryJob.
        The type of the discovery job. It defines the job's scope.
        NEW identifies new sensitive columns in the target database that are not in the sensitive data model.
        DELETED identifies columns that are present in the sensitive data model but have been deleted from the target database.
        MODIFIED identifies columns that are present in the target database as well as the sensitive data model but some of their attributes have been modified.
        ALL covers all the above three scenarios and reports new, deleted and modified columns.


        :param discovery_type: The discovery_type of this DiscoveryJob.
        :type: str
        """
        allowed_values = ["ALL", "NEW", "MODIFIED", "DELETED"]
        if not value_allowed_none_or_none_sentinel(discovery_type, allowed_values):
            discovery_type = 'UNKNOWN_ENUM_VALUE'
        self._discovery_type = discovery_type

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this DiscoveryJob.
        The display name of the discovery job.


        :return: The display_name of this DiscoveryJob.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DiscoveryJob.
        The display name of the discovery job.


        :param display_name: The display_name of this DiscoveryJob.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this DiscoveryJob.
        The OCID of the compartment that contains the discovery job.


        :return: The compartment_id of this DiscoveryJob.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DiscoveryJob.
        The OCID of the compartment that contains the discovery job.


        :param compartment_id: The compartment_id of this DiscoveryJob.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def time_started(self):
        """
        **[Required]** Gets the time_started of this DiscoveryJob.
        The date and time the discovery job started, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_started of this DiscoveryJob.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this DiscoveryJob.
        The date and time the discovery job started, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_started: The time_started of this DiscoveryJob.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_finished(self):
        """
        **[Required]** Gets the time_finished of this DiscoveryJob.
        The date and time the discovery job finished, in the format defined by `RFC3339`__..

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_finished of this DiscoveryJob.
        :rtype: datetime
        """
        return self._time_finished

    @time_finished.setter
    def time_finished(self, time_finished):
        """
        Sets the time_finished of this DiscoveryJob.
        The date and time the discovery job finished, in the format defined by `RFC3339`__..

        __ https://tools.ietf.org/html/rfc3339


        :param time_finished: The time_finished of this DiscoveryJob.
        :type: datetime
        """
        self._time_finished = time_finished

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this DiscoveryJob.
        The current state of the discovery job.

        Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DiscoveryJob.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DiscoveryJob.
        The current state of the discovery job.


        :param lifecycle_state: The lifecycle_state of this DiscoveryJob.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def sensitive_data_model_id(self):
        """
        **[Required]** Gets the sensitive_data_model_id of this DiscoveryJob.
        The OCID of the sensitive data model associated with the discovery job.


        :return: The sensitive_data_model_id of this DiscoveryJob.
        :rtype: str
        """
        return self._sensitive_data_model_id

    @sensitive_data_model_id.setter
    def sensitive_data_model_id(self, sensitive_data_model_id):
        """
        Sets the sensitive_data_model_id of this DiscoveryJob.
        The OCID of the sensitive data model associated with the discovery job.


        :param sensitive_data_model_id: The sensitive_data_model_id of this DiscoveryJob.
        :type: str
        """
        self._sensitive_data_model_id = sensitive_data_model_id

    @property
    def target_id(self):
        """
        **[Required]** Gets the target_id of this DiscoveryJob.
        The OCID of the target database associated with the discovery job.


        :return: The target_id of this DiscoveryJob.
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """
        Sets the target_id of this DiscoveryJob.
        The OCID of the target database associated with the discovery job.


        :param target_id: The target_id of this DiscoveryJob.
        :type: str
        """
        self._target_id = target_id

    @property
    def schemas_for_discovery(self):
        """
        Gets the schemas_for_discovery of this DiscoveryJob.
        The schemas used for data discovery.


        :return: The schemas_for_discovery of this DiscoveryJob.
        :rtype: list[str]
        """
        return self._schemas_for_discovery

    @schemas_for_discovery.setter
    def schemas_for_discovery(self, schemas_for_discovery):
        """
        Sets the schemas_for_discovery of this DiscoveryJob.
        The schemas used for data discovery.


        :param schemas_for_discovery: The schemas_for_discovery of this DiscoveryJob.
        :type: list[str]
        """
        self._schemas_for_discovery = schemas_for_discovery

    @property
    def sensitive_type_ids_for_discovery(self):
        """
        Gets the sensitive_type_ids_for_discovery of this DiscoveryJob.
        The OCIDs of the sensitive types used for data discovery.


        :return: The sensitive_type_ids_for_discovery of this DiscoveryJob.
        :rtype: list[str]
        """
        return self._sensitive_type_ids_for_discovery

    @sensitive_type_ids_for_discovery.setter
    def sensitive_type_ids_for_discovery(self, sensitive_type_ids_for_discovery):
        """
        Sets the sensitive_type_ids_for_discovery of this DiscoveryJob.
        The OCIDs of the sensitive types used for data discovery.


        :param sensitive_type_ids_for_discovery: The sensitive_type_ids_for_discovery of this DiscoveryJob.
        :type: list[str]
        """
        self._sensitive_type_ids_for_discovery = sensitive_type_ids_for_discovery

    @property
    def is_sample_data_collection_enabled(self):
        """
        **[Required]** Gets the is_sample_data_collection_enabled of this DiscoveryJob.
        Indicates if the discovery job should collect and store sample data values for the discovered columns.
        Sample data helps review the discovered columns and ensure that they actually contain sensitive data.
        As it collects original data from the target database, it's disabled by default and should be used only
        if it's acceptable to store sample data in Data Safe's repository in Oracle Cloud. Note that sample data
        values are not collected for columns with the following data types: LONG, LOB, RAW, XMLTYPE and BFILE.


        :return: The is_sample_data_collection_enabled of this DiscoveryJob.
        :rtype: bool
        """
        return self._is_sample_data_collection_enabled

    @is_sample_data_collection_enabled.setter
    def is_sample_data_collection_enabled(self, is_sample_data_collection_enabled):
        """
        Sets the is_sample_data_collection_enabled of this DiscoveryJob.
        Indicates if the discovery job should collect and store sample data values for the discovered columns.
        Sample data helps review the discovered columns and ensure that they actually contain sensitive data.
        As it collects original data from the target database, it's disabled by default and should be used only
        if it's acceptable to store sample data in Data Safe's repository in Oracle Cloud. Note that sample data
        values are not collected for columns with the following data types: LONG, LOB, RAW, XMLTYPE and BFILE.


        :param is_sample_data_collection_enabled: The is_sample_data_collection_enabled of this DiscoveryJob.
        :type: bool
        """
        self._is_sample_data_collection_enabled = is_sample_data_collection_enabled

    @property
    def is_app_defined_relation_discovery_enabled(self):
        """
        **[Required]** Gets the is_app_defined_relation_discovery_enabled of this DiscoveryJob.
        Indicates if the discovery job should identify potential application-level (non-dictionary) referential
        relationships between columns. Note that data discovery automatically identifies and adds database-level (dictionary-defined)
        relationships. This option helps identify application-level relationships that are not defined in the database dictionary,
        which in turn, helps identify additional sensitive columns and preserve referential integrity during data masking.
        It's disabled by default and should be used only if there is a need to identify application-level relationships.


        :return: The is_app_defined_relation_discovery_enabled of this DiscoveryJob.
        :rtype: bool
        """
        return self._is_app_defined_relation_discovery_enabled

    @is_app_defined_relation_discovery_enabled.setter
    def is_app_defined_relation_discovery_enabled(self, is_app_defined_relation_discovery_enabled):
        """
        Sets the is_app_defined_relation_discovery_enabled of this DiscoveryJob.
        Indicates if the discovery job should identify potential application-level (non-dictionary) referential
        relationships between columns. Note that data discovery automatically identifies and adds database-level (dictionary-defined)
        relationships. This option helps identify application-level relationships that are not defined in the database dictionary,
        which in turn, helps identify additional sensitive columns and preserve referential integrity during data masking.
        It's disabled by default and should be used only if there is a need to identify application-level relationships.


        :param is_app_defined_relation_discovery_enabled: The is_app_defined_relation_discovery_enabled of this DiscoveryJob.
        :type: bool
        """
        self._is_app_defined_relation_discovery_enabled = is_app_defined_relation_discovery_enabled

    @property
    def is_include_all_schemas(self):
        """
        **[Required]** Gets the is_include_all_schemas of this DiscoveryJob.
        Indicates if all the schemas in the associated target database are used for data discovery.
        If it's set to true, the schemasForDiscovery attribute is ignored and all schemas are used.


        :return: The is_include_all_schemas of this DiscoveryJob.
        :rtype: bool
        """
        return self._is_include_all_schemas

    @is_include_all_schemas.setter
    def is_include_all_schemas(self, is_include_all_schemas):
        """
        Sets the is_include_all_schemas of this DiscoveryJob.
        Indicates if all the schemas in the associated target database are used for data discovery.
        If it's set to true, the schemasForDiscovery attribute is ignored and all schemas are used.


        :param is_include_all_schemas: The is_include_all_schemas of this DiscoveryJob.
        :type: bool
        """
        self._is_include_all_schemas = is_include_all_schemas

    @property
    def is_include_all_sensitive_types(self):
        """
        **[Required]** Gets the is_include_all_sensitive_types of this DiscoveryJob.
        Indicates if all the existing sensitive types are used for data discovery. If it's set to true, the
        sensitiveTypeIdsForDiscovery attribute is ignored and all sensitive types are used.


        :return: The is_include_all_sensitive_types of this DiscoveryJob.
        :rtype: bool
        """
        return self._is_include_all_sensitive_types

    @is_include_all_sensitive_types.setter
    def is_include_all_sensitive_types(self, is_include_all_sensitive_types):
        """
        Sets the is_include_all_sensitive_types of this DiscoveryJob.
        Indicates if all the existing sensitive types are used for data discovery. If it's set to true, the
        sensitiveTypeIdsForDiscovery attribute is ignored and all sensitive types are used.


        :param is_include_all_sensitive_types: The is_include_all_sensitive_types of this DiscoveryJob.
        :type: bool
        """
        self._is_include_all_sensitive_types = is_include_all_sensitive_types

    @property
    def total_schemas_scanned(self):
        """
        **[Required]** Gets the total_schemas_scanned of this DiscoveryJob.
        The total number of schemas scanned by the discovery job.


        :return: The total_schemas_scanned of this DiscoveryJob.
        :rtype: int
        """
        return self._total_schemas_scanned

    @total_schemas_scanned.setter
    def total_schemas_scanned(self, total_schemas_scanned):
        """
        Sets the total_schemas_scanned of this DiscoveryJob.
        The total number of schemas scanned by the discovery job.


        :param total_schemas_scanned: The total_schemas_scanned of this DiscoveryJob.
        :type: int
        """
        self._total_schemas_scanned = total_schemas_scanned

    @property
    def total_objects_scanned(self):
        """
        **[Required]** Gets the total_objects_scanned of this DiscoveryJob.
        The total number of objects (tables and editioning views) scanned by the discovery job.


        :return: The total_objects_scanned of this DiscoveryJob.
        :rtype: int
        """
        return self._total_objects_scanned

    @total_objects_scanned.setter
    def total_objects_scanned(self, total_objects_scanned):
        """
        Sets the total_objects_scanned of this DiscoveryJob.
        The total number of objects (tables and editioning views) scanned by the discovery job.


        :param total_objects_scanned: The total_objects_scanned of this DiscoveryJob.
        :type: int
        """
        self._total_objects_scanned = total_objects_scanned

    @property
    def total_columns_scanned(self):
        """
        **[Required]** Gets the total_columns_scanned of this DiscoveryJob.
        The total number of columns scanned by the discovery job.


        :return: The total_columns_scanned of this DiscoveryJob.
        :rtype: int
        """
        return self._total_columns_scanned

    @total_columns_scanned.setter
    def total_columns_scanned(self, total_columns_scanned):
        """
        Sets the total_columns_scanned of this DiscoveryJob.
        The total number of columns scanned by the discovery job.


        :param total_columns_scanned: The total_columns_scanned of this DiscoveryJob.
        :type: int
        """
        self._total_columns_scanned = total_columns_scanned

    @property
    def total_new_sensitive_columns(self):
        """
        **[Required]** Gets the total_new_sensitive_columns of this DiscoveryJob.
        The total number of new sensitive columns identified by the discovery job.


        :return: The total_new_sensitive_columns of this DiscoveryJob.
        :rtype: int
        """
        return self._total_new_sensitive_columns

    @total_new_sensitive_columns.setter
    def total_new_sensitive_columns(self, total_new_sensitive_columns):
        """
        Sets the total_new_sensitive_columns of this DiscoveryJob.
        The total number of new sensitive columns identified by the discovery job.


        :param total_new_sensitive_columns: The total_new_sensitive_columns of this DiscoveryJob.
        :type: int
        """
        self._total_new_sensitive_columns = total_new_sensitive_columns

    @property
    def total_modified_sensitive_columns(self):
        """
        **[Required]** Gets the total_modified_sensitive_columns of this DiscoveryJob.
        The total number of modified sensitive columns identified by the discovery job.


        :return: The total_modified_sensitive_columns of this DiscoveryJob.
        :rtype: int
        """
        return self._total_modified_sensitive_columns

    @total_modified_sensitive_columns.setter
    def total_modified_sensitive_columns(self, total_modified_sensitive_columns):
        """
        Sets the total_modified_sensitive_columns of this DiscoveryJob.
        The total number of modified sensitive columns identified by the discovery job.


        :param total_modified_sensitive_columns: The total_modified_sensitive_columns of this DiscoveryJob.
        :type: int
        """
        self._total_modified_sensitive_columns = total_modified_sensitive_columns

    @property
    def total_deleted_sensitive_columns(self):
        """
        **[Required]** Gets the total_deleted_sensitive_columns of this DiscoveryJob.
        The total number of deleted sensitive columns identified by the discovery job.


        :return: The total_deleted_sensitive_columns of this DiscoveryJob.
        :rtype: int
        """
        return self._total_deleted_sensitive_columns

    @total_deleted_sensitive_columns.setter
    def total_deleted_sensitive_columns(self, total_deleted_sensitive_columns):
        """
        Sets the total_deleted_sensitive_columns of this DiscoveryJob.
        The total number of deleted sensitive columns identified by the discovery job.


        :param total_deleted_sensitive_columns: The total_deleted_sensitive_columns of this DiscoveryJob.
        :type: int
        """
        self._total_deleted_sensitive_columns = total_deleted_sensitive_columns

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DiscoveryJob.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this DiscoveryJob.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DiscoveryJob.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this DiscoveryJob.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DiscoveryJob.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this DiscoveryJob.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DiscoveryJob.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this DiscoveryJob.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this DiscoveryJob.
        System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this DiscoveryJob.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this DiscoveryJob.
        System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this DiscoveryJob.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ModifyVcnCidrDetails(object):
    """
    Details for updating a CIDR block.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ModifyVcnCidrDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param original_cidr_block:
            The value to assign to the original_cidr_block property of this ModifyVcnCidrDetails.
        :type original_cidr_block: str

        :param new_cidr_block:
            The value to assign to the new_cidr_block property of this ModifyVcnCidrDetails.
        :type new_cidr_block: str

        """
        self.swagger_types = {
            'original_cidr_block': 'str',
            'new_cidr_block': 'str'
        }

        self.attribute_map = {
            'original_cidr_block': 'originalCidrBlock',
            'new_cidr_block': 'newCidrBlock'
        }

        self._original_cidr_block = None
        self._new_cidr_block = None

    @property
    def original_cidr_block(self):
        """
        **[Required]** Gets the original_cidr_block of this ModifyVcnCidrDetails.
        The CIDR IP address to update.


        :return: The original_cidr_block of this ModifyVcnCidrDetails.
        :rtype: str
        """
        return self._original_cidr_block

    @original_cidr_block.setter
    def original_cidr_block(self, original_cidr_block):
        """
        Sets the original_cidr_block of this ModifyVcnCidrDetails.
        The CIDR IP address to update.


        :param original_cidr_block: The original_cidr_block of this ModifyVcnCidrDetails.
        :type: str
        """
        self._original_cidr_block = original_cidr_block

    @property
    def new_cidr_block(self):
        """
        **[Required]** Gets the new_cidr_block of this ModifyVcnCidrDetails.
        The new CIDR IP address.


        :return: The new_cidr_block of this ModifyVcnCidrDetails.
        :rtype: str
        """
        return self._new_cidr_block

    @new_cidr_block.setter
    def new_cidr_block(self, new_cidr_block):
        """
        Sets the new_cidr_block of this ModifyVcnCidrDetails.
        The new CIDR IP address.


        :param new_cidr_block: The new_cidr_block of this ModifyVcnCidrDetails.
        :type: str
        """
        self._new_cidr_block = new_cidr_block

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PrivateEndpointSummary(object):
    """
    The summary metadata associated with the private endpoint.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PrivateEndpointSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this PrivateEndpointSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this PrivateEndpointSummary.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this PrivateEndpointSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this PrivateEndpointSummary.
        :type description: str

        :param vcn_id:
            The value to assign to the vcn_id property of this PrivateEndpointSummary.
        :type vcn_id: str

        :param is_used_with_configuration_source_provider:
            The value to assign to the is_used_with_configuration_source_provider property of this PrivateEndpointSummary.
        :type is_used_with_configuration_source_provider: bool

        :param dns_zones:
            The value to assign to the dns_zones property of this PrivateEndpointSummary.
        :type dns_zones: list[str]

        :param time_created:
            The value to assign to the time_created property of this PrivateEndpointSummary.
        :type time_created: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this PrivateEndpointSummary.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this PrivateEndpointSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this PrivateEndpointSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'description': 'str',
            'vcn_id': 'str',
            'is_used_with_configuration_source_provider': 'bool',
            'dns_zones': 'list[str]',
            'time_created': 'datetime',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'description': 'description',
            'vcn_id': 'vcnId',
            'is_used_with_configuration_source_provider': 'isUsedWithConfigurationSourceProvider',
            'dns_zones': 'dnsZones',
            'time_created': 'timeCreated',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._description = None
        self._vcn_id = None
        self._is_used_with_configuration_source_provider = None
        self._dns_zones = None
        self._time_created = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this PrivateEndpointSummary.
        Unique identifier (`OCID`__) of the private endpoint.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this PrivateEndpointSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this PrivateEndpointSummary.
        Unique identifier (`OCID`__) of the private endpoint.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this PrivateEndpointSummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this PrivateEndpointSummary.
        The `OCID`__ of the compartment containing this private endpoint details.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this PrivateEndpointSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this PrivateEndpointSummary.
        The `OCID`__ of the compartment containing this private endpoint details.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this PrivateEndpointSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this PrivateEndpointSummary.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :return: The display_name of this PrivateEndpointSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this PrivateEndpointSummary.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :param display_name: The display_name of this PrivateEndpointSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this PrivateEndpointSummary.
        General description of the private endpoint.


        :return: The description of this PrivateEndpointSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this PrivateEndpointSummary.
        General description of the private endpoint.


        :param description: The description of this PrivateEndpointSummary.
        :type: str
        """
        self._description = description

    @property
    def vcn_id(self):
        """
        **[Required]** Gets the vcn_id of this PrivateEndpointSummary.
        The `OCID`__ of the VCN for the private endpoint.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The vcn_id of this PrivateEndpointSummary.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this PrivateEndpointSummary.
        The `OCID`__ of the VCN for the private endpoint.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param vcn_id: The vcn_id of this PrivateEndpointSummary.
        :type: str
        """
        self._vcn_id = vcn_id

    @property
    def is_used_with_configuration_source_provider(self):
        """
        Gets the is_used_with_configuration_source_provider of this PrivateEndpointSummary.
        When `true`, allows the private endpoint to be used with a configuration source provider.


        :return: The is_used_with_configuration_source_provider of this PrivateEndpointSummary.
        :rtype: bool
        """
        return self._is_used_with_configuration_source_provider

    @is_used_with_configuration_source_provider.setter
    def is_used_with_configuration_source_provider(self, is_used_with_configuration_source_provider):
        """
        Sets the is_used_with_configuration_source_provider of this PrivateEndpointSummary.
        When `true`, allows the private endpoint to be used with a configuration source provider.


        :param is_used_with_configuration_source_provider: The is_used_with_configuration_source_provider of this PrivateEndpointSummary.
        :type: bool
        """
        self._is_used_with_configuration_source_provider = is_used_with_configuration_source_provider

    @property
    def dns_zones(self):
        """
        Gets the dns_zones of this PrivateEndpointSummary.
        DNS Proxy forwards any DNS FQDN queries over into the consumer DNS resolver if the DNS FQDN is included in the dns zones list otherwise it goes to service provider VCN resolver.


        :return: The dns_zones of this PrivateEndpointSummary.
        :rtype: list[str]
        """
        return self._dns_zones

    @dns_zones.setter
    def dns_zones(self, dns_zones):
        """
        Sets the dns_zones of this PrivateEndpointSummary.
        DNS Proxy forwards any DNS FQDN queries over into the consumer DNS resolver if the DNS FQDN is included in the dns zones list otherwise it goes to service provider VCN resolver.


        :param dns_zones: The dns_zones of this PrivateEndpointSummary.
        :type: list[str]
        """
        self._dns_zones = dns_zones

    @property
    def time_created(self):
        """
        Gets the time_created of this PrivateEndpointSummary.
        The date and time when the private endpoint was created.
        Format is defined by RFC3339.
        Example: `2020-01-25T21:10:29.600Z`


        :return: The time_created of this PrivateEndpointSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this PrivateEndpointSummary.
        The date and time when the private endpoint was created.
        Format is defined by RFC3339.
        Example: `2020-01-25T21:10:29.600Z`


        :param time_created: The time_created of this PrivateEndpointSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this PrivateEndpointSummary.
        The current lifecycle state of the private endpoint.
        Allowable values:
        - ACTIVE
        - CREATING
        - DELETING
        - DELETED
        - FAILED


        :return: The lifecycle_state of this PrivateEndpointSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this PrivateEndpointSummary.
        The current lifecycle state of the private endpoint.
        Allowable values:
        - ACTIVE
        - CREATING
        - DELETING
        - DELETED
        - FAILED


        :param lifecycle_state: The lifecycle_state of this PrivateEndpointSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this PrivateEndpointSummary.
        Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this PrivateEndpointSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this PrivateEndpointSummary.
        Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this PrivateEndpointSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this PrivateEndpointSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this PrivateEndpointSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this PrivateEndpointSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this PrivateEndpointSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ComputedUsageProduct(object):
    """
    Product description
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ComputedUsageProduct object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param part_number:
            The value to assign to the part_number property of this ComputedUsageProduct.
        :type part_number: str

        :param name:
            The value to assign to the name property of this ComputedUsageProduct.
        :type name: str

        :param unit_of_measure:
            The value to assign to the unit_of_measure property of this ComputedUsageProduct.
        :type unit_of_measure: str

        :param provisioning_group:
            The value to assign to the provisioning_group property of this ComputedUsageProduct.
        :type provisioning_group: str

        :param billing_category:
            The value to assign to the billing_category property of this ComputedUsageProduct.
        :type billing_category: str

        :param product_category:
            The value to assign to the product_category property of this ComputedUsageProduct.
        :type product_category: str

        :param ucm_rate_card_part_type:
            The value to assign to the ucm_rate_card_part_type property of this ComputedUsageProduct.
        :type ucm_rate_card_part_type: str

        """
        self.swagger_types = {
            'part_number': 'str',
            'name': 'str',
            'unit_of_measure': 'str',
            'provisioning_group': 'str',
            'billing_category': 'str',
            'product_category': 'str',
            'ucm_rate_card_part_type': 'str'
        }

        self.attribute_map = {
            'part_number': 'partNumber',
            'name': 'name',
            'unit_of_measure': 'unitOfMeasure',
            'provisioning_group': 'provisioningGroup',
            'billing_category': 'billingCategory',
            'product_category': 'productCategory',
            'ucm_rate_card_part_type': 'ucmRateCardPartType'
        }

        self._part_number = None
        self._name = None
        self._unit_of_measure = None
        self._provisioning_group = None
        self._billing_category = None
        self._product_category = None
        self._ucm_rate_card_part_type = None

    @property
    def part_number(self):
        """
        **[Required]** Gets the part_number of this ComputedUsageProduct.
        Product part number


        :return: The part_number of this ComputedUsageProduct.
        :rtype: str
        """
        return self._part_number

    @part_number.setter
    def part_number(self, part_number):
        """
        Sets the part_number of this ComputedUsageProduct.
        Product part number


        :param part_number: The part_number of this ComputedUsageProduct.
        :type: str
        """
        self._part_number = part_number

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ComputedUsageProduct.
        Product name


        :return: The name of this ComputedUsageProduct.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ComputedUsageProduct.
        Product name


        :param name: The name of this ComputedUsageProduct.
        :type: str
        """
        self._name = name

    @property
    def unit_of_measure(self):
        """
        Gets the unit_of_measure of this ComputedUsageProduct.
        Unit of Measure


        :return: The unit_of_measure of this ComputedUsageProduct.
        :rtype: str
        """
        return self._unit_of_measure

    @unit_of_measure.setter
    def unit_of_measure(self, unit_of_measure):
        """
        Sets the unit_of_measure of this ComputedUsageProduct.
        Unit of Measure


        :param unit_of_measure: The unit_of_measure of this ComputedUsageProduct.
        :type: str
        """
        self._unit_of_measure = unit_of_measure

    @property
    def provisioning_group(self):
        """
        Gets the provisioning_group of this ComputedUsageProduct.
        Product provisioning group


        :return: The provisioning_group of this ComputedUsageProduct.
        :rtype: str
        """
        return self._provisioning_group

    @provisioning_group.setter
    def provisioning_group(self, provisioning_group):
        """
        Sets the provisioning_group of this ComputedUsageProduct.
        Product provisioning group


        :param provisioning_group: The provisioning_group of this ComputedUsageProduct.
        :type: str
        """
        self._provisioning_group = provisioning_group

    @property
    def billing_category(self):
        """
        Gets the billing_category of this ComputedUsageProduct.
        Metered service billing category


        :return: The billing_category of this ComputedUsageProduct.
        :rtype: str
        """
        return self._billing_category

    @billing_category.setter
    def billing_category(self, billing_category):
        """
        Sets the billing_category of this ComputedUsageProduct.
        Metered service billing category


        :param billing_category: The billing_category of this ComputedUsageProduct.
        :type: str
        """
        self._billing_category = billing_category

    @property
    def product_category(self):
        """
        Gets the product_category of this ComputedUsageProduct.
        Product category


        :return: The product_category of this ComputedUsageProduct.
        :rtype: str
        """
        return self._product_category

    @product_category.setter
    def product_category(self, product_category):
        """
        Sets the product_category of this ComputedUsageProduct.
        Product category


        :param product_category: The product_category of this ComputedUsageProduct.
        :type: str
        """
        self._product_category = product_category

    @property
    def ucm_rate_card_part_type(self):
        """
        Gets the ucm_rate_card_part_type of this ComputedUsageProduct.
        Rate card part type of Product


        :return: The ucm_rate_card_part_type of this ComputedUsageProduct.
        :rtype: str
        """
        return self._ucm_rate_card_part_type

    @ucm_rate_card_part_type.setter
    def ucm_rate_card_part_type(self, ucm_rate_card_part_type):
        """
        Sets the ucm_rate_card_part_type of this ComputedUsageProduct.
        Rate card part type of Product


        :param ucm_rate_card_part_type: The ucm_rate_card_part_type of this ComputedUsageProduct.
        :type: str
        """
        self._ucm_rate_card_part_type = ucm_rate_card_part_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateAuditProfileDetails(object):
    """
    The details used to create a new audit profile.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateAuditProfileDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateAuditProfileDetails.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateAuditProfileDetails.
        :type compartment_id: str

        :param target_id:
            The value to assign to the target_id property of this CreateAuditProfileDetails.
        :type target_id: str

        :param description:
            The value to assign to the description property of this CreateAuditProfileDetails.
        :type description: str

        :param is_paid_usage_enabled:
            The value to assign to the is_paid_usage_enabled property of this CreateAuditProfileDetails.
        :type is_paid_usage_enabled: bool

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateAuditProfileDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateAuditProfileDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'compartment_id': 'str',
            'target_id': 'str',
            'description': 'str',
            'is_paid_usage_enabled': 'bool',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'target_id': 'targetId',
            'description': 'description',
            'is_paid_usage_enabled': 'isPaidUsageEnabled',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._compartment_id = None
        self._target_id = None
        self._description = None
        self._is_paid_usage_enabled = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateAuditProfileDetails.
        The display name of the audit profile. The name does not have to be unique, and it's changeable.


        :return: The display_name of this CreateAuditProfileDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateAuditProfileDetails.
        The display name of the audit profile. The name does not have to be unique, and it's changeable.


        :param display_name: The display_name of this CreateAuditProfileDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateAuditProfileDetails.
        The OCID of the compartment where you want to create the audit profile.


        :return: The compartment_id of this CreateAuditProfileDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateAuditProfileDetails.
        The OCID of the compartment where you want to create the audit profile.


        :param compartment_id: The compartment_id of this CreateAuditProfileDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def target_id(self):
        """
        **[Required]** Gets the target_id of this CreateAuditProfileDetails.
        The OCID of the Data Safe target for which the audit profile is created.


        :return: The target_id of this CreateAuditProfileDetails.
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """
        Sets the target_id of this CreateAuditProfileDetails.
        The OCID of the Data Safe target for which the audit profile is created.


        :param target_id: The target_id of this CreateAuditProfileDetails.
        :type: str
        """
        self._target_id = target_id

    @property
    def description(self):
        """
        Gets the description of this CreateAuditProfileDetails.
        The description of the audit profile.


        :return: The description of this CreateAuditProfileDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateAuditProfileDetails.
        The description of the audit profile.


        :param description: The description of this CreateAuditProfileDetails.
        :type: str
        """
        self._description = description

    @property
    def is_paid_usage_enabled(self):
        """
        Gets the is_paid_usage_enabled of this CreateAuditProfileDetails.
        Indicates if you want to continue collecting audit records beyond the free limit of one million audit records per month per target database,
        potentially incurring additional charges. The default value is inherited from the global settings.
        You can change at the global level or at the target level.


        :return: The is_paid_usage_enabled of this CreateAuditProfileDetails.
        :rtype: bool
        """
        return self._is_paid_usage_enabled

    @is_paid_usage_enabled.setter
    def is_paid_usage_enabled(self, is_paid_usage_enabled):
        """
        Sets the is_paid_usage_enabled of this CreateAuditProfileDetails.
        Indicates if you want to continue collecting audit records beyond the free limit of one million audit records per month per target database,
        potentially incurring additional charges. The default value is inherited from the global settings.
        You can change at the global level or at the target level.


        :param is_paid_usage_enabled: The is_paid_usage_enabled of this CreateAuditProfileDetails.
        :type: bool
        """
        self._is_paid_usage_enabled = is_paid_usage_enabled

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateAuditProfileDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateAuditProfileDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateAuditProfileDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateAuditProfileDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateAuditProfileDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateAuditProfileDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateAuditProfileDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateAuditProfileDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DecryptionRule(object):
    """
    Decryption Rule used in the firewall policy rules.
    A Decryption Rule is used to define which traffic should be decrypted by the firewall, and how it should do so.
    """

    #: A constant which can be used with the action property of a DecryptionRule.
    #: This constant has a value of "NO_DECRYPT"
    ACTION_NO_DECRYPT = "NO_DECRYPT"

    #: A constant which can be used with the action property of a DecryptionRule.
    #: This constant has a value of "DECRYPT"
    ACTION_DECRYPT = "DECRYPT"

    def __init__(self, **kwargs):
        """
        Initializes a new DecryptionRule object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this DecryptionRule.
        :type name: str

        :param condition:
            The value to assign to the condition property of this DecryptionRule.
        :type condition: oci.network_firewall.models.DecryptionRuleMatchCriteria

        :param action:
            The value to assign to the action property of this DecryptionRule.
            Allowed values for this property are: "NO_DECRYPT", "DECRYPT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type action: str

        :param decryption_profile:
            The value to assign to the decryption_profile property of this DecryptionRule.
        :type decryption_profile: str

        :param secret:
            The value to assign to the secret property of this DecryptionRule.
        :type secret: str

        """
        self.swagger_types = {
            'name': 'str',
            'condition': 'DecryptionRuleMatchCriteria',
            'action': 'str',
            'decryption_profile': 'str',
            'secret': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'condition': 'condition',
            'action': 'action',
            'decryption_profile': 'decryptionProfile',
            'secret': 'secret'
        }

        self._name = None
        self._condition = None
        self._action = None
        self._decryption_profile = None
        self._secret = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this DecryptionRule.
        Name for the decryption rule, must be unique within the policy.


        :return: The name of this DecryptionRule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DecryptionRule.
        Name for the decryption rule, must be unique within the policy.


        :param name: The name of this DecryptionRule.
        :type: str
        """
        self._name = name

    @property
    def condition(self):
        """
        **[Required]** Gets the condition of this DecryptionRule.

        :return: The condition of this DecryptionRule.
        :rtype: oci.network_firewall.models.DecryptionRuleMatchCriteria
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """
        Sets the condition of this DecryptionRule.

        :param condition: The condition of this DecryptionRule.
        :type: oci.network_firewall.models.DecryptionRuleMatchCriteria
        """
        self._condition = condition

    @property
    def action(self):
        """
        **[Required]** Gets the action of this DecryptionRule.
        Action:

        * NO_DECRYPT - Matching traffic is not decrypted.
        * DECRYPT - Matching traffic is decrypted with the specified `secret` according to the specified `decryptionProfile`.

        Allowed values for this property are: "NO_DECRYPT", "DECRYPT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The action of this DecryptionRule.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this DecryptionRule.
        Action:

        * NO_DECRYPT - Matching traffic is not decrypted.
        * DECRYPT - Matching traffic is decrypted with the specified `secret` according to the specified `decryptionProfile`.


        :param action: The action of this DecryptionRule.
        :type: str
        """
        allowed_values = ["NO_DECRYPT", "DECRYPT"]
        if not value_allowed_none_or_none_sentinel(action, allowed_values):
            action = 'UNKNOWN_ENUM_VALUE'
        self._action = action

    @property
    def decryption_profile(self):
        """
        Gets the decryption_profile of this DecryptionRule.
        The name of the decryption profile to use.


        :return: The decryption_profile of this DecryptionRule.
        :rtype: str
        """
        return self._decryption_profile

    @decryption_profile.setter
    def decryption_profile(self, decryption_profile):
        """
        Sets the decryption_profile of this DecryptionRule.
        The name of the decryption profile to use.


        :param decryption_profile: The decryption_profile of this DecryptionRule.
        :type: str
        """
        self._decryption_profile = decryption_profile

    @property
    def secret(self):
        """
        Gets the secret of this DecryptionRule.
        The name of a mapped secret. Its `type` must match that of the specified decryption profile.


        :return: The secret of this DecryptionRule.
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """
        Sets the secret of this DecryptionRule.
        The name of a mapped secret. Its `type` must match that of the specified decryption profile.


        :param secret: The secret of this DecryptionRule.
        :type: str
        """
        self._secret = secret

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EgressTrafficSpec(object):
    """
    Defines the traffic configuration that leaves the traffic node.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new EgressTrafficSpec object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param protocol:
            The value to assign to the protocol property of this EgressTrafficSpec.
        :type protocol: int

        :param source_address:
            The value to assign to the source_address property of this EgressTrafficSpec.
        :type source_address: str

        :param destination_address:
            The value to assign to the destination_address property of this EgressTrafficSpec.
        :type destination_address: str

        :param traffic_protocol_parameters:
            The value to assign to the traffic_protocol_parameters property of this EgressTrafficSpec.
        :type traffic_protocol_parameters: oci.vn_monitoring.models.TrafficProtocolParameters

        """
        self.swagger_types = {
            'protocol': 'int',
            'source_address': 'str',
            'destination_address': 'str',
            'traffic_protocol_parameters': 'TrafficProtocolParameters'
        }

        self.attribute_map = {
            'protocol': 'protocol',
            'source_address': 'sourceAddress',
            'destination_address': 'destinationAddress',
            'traffic_protocol_parameters': 'trafficProtocolParameters'
        }

        self._protocol = None
        self._source_address = None
        self._destination_address = None
        self._traffic_protocol_parameters = None

    @property
    def protocol(self):
        """
        **[Required]** Gets the protocol of this EgressTrafficSpec.
        The IP protocol to use for the traffic path analysis.


        :return: The protocol of this EgressTrafficSpec.
        :rtype: int
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this EgressTrafficSpec.
        The IP protocol to use for the traffic path analysis.


        :param protocol: The protocol of this EgressTrafficSpec.
        :type: int
        """
        self._protocol = protocol

    @property
    def source_address(self):
        """
        **[Required]** Gets the source_address of this EgressTrafficSpec.
        The IPv4 address of the source node.


        :return: The source_address of this EgressTrafficSpec.
        :rtype: str
        """
        return self._source_address

    @source_address.setter
    def source_address(self, source_address):
        """
        Sets the source_address of this EgressTrafficSpec.
        The IPv4 address of the source node.


        :param source_address: The source_address of this EgressTrafficSpec.
        :type: str
        """
        self._source_address = source_address

    @property
    def destination_address(self):
        """
        **[Required]** Gets the destination_address of this EgressTrafficSpec.
        The IPv4 address of the destination node.


        :return: The destination_address of this EgressTrafficSpec.
        :rtype: str
        """
        return self._destination_address

    @destination_address.setter
    def destination_address(self, destination_address):
        """
        Sets the destination_address of this EgressTrafficSpec.
        The IPv4 address of the destination node.


        :param destination_address: The destination_address of this EgressTrafficSpec.
        :type: str
        """
        self._destination_address = destination_address

    @property
    def traffic_protocol_parameters(self):
        """
        Gets the traffic_protocol_parameters of this EgressTrafficSpec.

        :return: The traffic_protocol_parameters of this EgressTrafficSpec.
        :rtype: oci.vn_monitoring.models.TrafficProtocolParameters
        """
        return self._traffic_protocol_parameters

    @traffic_protocol_parameters.setter
    def traffic_protocol_parameters(self, traffic_protocol_parameters):
        """
        Sets the traffic_protocol_parameters of this EgressTrafficSpec.

        :param traffic_protocol_parameters: The traffic_protocol_parameters of this EgressTrafficSpec.
        :type: oci.vn_monitoring.models.TrafficProtocolParameters
        """
        self._traffic_protocol_parameters = traffic_protocol_parameters

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AddLockDetails(object):
    """
    Request payload to add lock to the resource. The FULL lock type allows no modifications (delete, create, update).
    The DELETE lock type allows all modifications, but delete is not allowed.
    """

    #: A constant which can be used with the type property of a AddLockDetails.
    #: This constant has a value of "FULL"
    TYPE_FULL = "FULL"

    #: A constant which can be used with the type property of a AddLockDetails.
    #: This constant has a value of "DELETE"
    TYPE_DELETE = "DELETE"

    def __init__(self, **kwargs):
        """
        Initializes a new AddLockDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this AddLockDetails.
            Allowed values for this property are: "FULL", "DELETE"
        :type type: str

        :param related_resource_id:
            The value to assign to the related_resource_id property of this AddLockDetails.
        :type related_resource_id: str

        :param message:
            The value to assign to the message property of this AddLockDetails.
        :type message: str

        """
        self.swagger_types = {
            'type': 'str',
            'related_resource_id': 'str',
            'message': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'related_resource_id': 'relatedResourceId',
            'message': 'message'
        }

        self._type = None
        self._related_resource_id = None
        self._message = None

    @property
    def type(self):
        """
        **[Required]** Gets the type of this AddLockDetails.
        Lock type.

        Allowed values for this property are: "FULL", "DELETE"


        :return: The type of this AddLockDetails.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this AddLockDetails.
        Lock type.


        :param type: The type of this AddLockDetails.
        :type: str
        """
        allowed_values = ["FULL", "DELETE"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            raise ValueError(
                "Invalid value for `type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def related_resource_id(self):
        """
        Gets the related_resource_id of this AddLockDetails.
        The resource ID that is locking this resource. Indicates that deleting this resource removes the lock.


        :return: The related_resource_id of this AddLockDetails.
        :rtype: str
        """
        return self._related_resource_id

    @related_resource_id.setter
    def related_resource_id(self, related_resource_id):
        """
        Sets the related_resource_id of this AddLockDetails.
        The resource ID that is locking this resource. Indicates that deleting this resource removes the lock.


        :param related_resource_id: The related_resource_id of this AddLockDetails.
        :type: str
        """
        self._related_resource_id = related_resource_id

    @property
    def message(self):
        """
        Gets the message of this AddLockDetails.
        A message added by the lock creator. The message typically gives an
        indication of why the resource is locked.


        :return: The message of this AddLockDetails.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this AddLockDetails.
        A message added by the lock creator. The message typically gives an
        indication of why the resource is locked.


        :param message: The message of this AddLockDetails.
        :type: str
        """
        self._message = message

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .deployment import Deployment
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DeployPipelineDeployment(Deployment):
    """
    Deployment of all the stages in the pipeline.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DeployPipelineDeployment object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.DeployPipelineDeployment.deployment_type` attribute
        of this class is ``PIPELINE_DEPLOYMENT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param deploy_pipeline_artifacts:
            The value to assign to the deploy_pipeline_artifacts property of this DeployPipelineDeployment.
        :type deploy_pipeline_artifacts: oci.devops.models.DeployPipelineArtifactCollection

        :param deploy_pipeline_environments:
            The value to assign to the deploy_pipeline_environments property of this DeployPipelineDeployment.
        :type deploy_pipeline_environments: oci.devops.models.DeployPipelineEnvironmentCollection

        :param deployment_type:
            The value to assign to the deployment_type property of this DeployPipelineDeployment.
            Allowed values for this property are: "PIPELINE_DEPLOYMENT", "PIPELINE_REDEPLOYMENT", "SINGLE_STAGE_DEPLOYMENT", "SINGLE_STAGE_REDEPLOYMENT"
        :type deployment_type: str

        :param id:
            The value to assign to the id property of this DeployPipelineDeployment.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this DeployPipelineDeployment.
        :type display_name: str

        :param project_id:
            The value to assign to the project_id property of this DeployPipelineDeployment.
        :type project_id: str

        :param deploy_pipeline_id:
            The value to assign to the deploy_pipeline_id property of this DeployPipelineDeployment.
        :type deploy_pipeline_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DeployPipelineDeployment.
        :type compartment_id: str

        :param time_created:
            The value to assign to the time_created property of this DeployPipelineDeployment.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this DeployPipelineDeployment.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DeployPipelineDeployment.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED"
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this DeployPipelineDeployment.
        :type lifecycle_details: str

        :param deployment_arguments:
            The value to assign to the deployment_arguments property of this DeployPipelineDeployment.
        :type deployment_arguments: oci.devops.models.DeploymentArgumentCollection

        :param deploy_artifact_override_arguments:
            The value to assign to the deploy_artifact_override_arguments property of this DeployPipelineDeployment.
        :type deploy_artifact_override_arguments: oci.devops.models.DeployArtifactOverrideArgumentCollection

        :param deployment_execution_progress:
            The value to assign to the deployment_execution_progress property of this DeployPipelineDeployment.
        :type deployment_execution_progress: oci.devops.models.DeploymentExecutionProgress

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DeployPipelineDeployment.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DeployPipelineDeployment.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this DeployPipelineDeployment.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'deploy_pipeline_artifacts': 'DeployPipelineArtifactCollection',
            'deploy_pipeline_environments': 'DeployPipelineEnvironmentCollection',
            'deployment_type': 'str',
            'id': 'str',
            'display_name': 'str',
            'project_id': 'str',
            'deploy_pipeline_id': 'str',
            'compartment_id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'deployment_arguments': 'DeploymentArgumentCollection',
            'deploy_artifact_override_arguments': 'DeployArtifactOverrideArgumentCollection',
            'deployment_execution_progress': 'DeploymentExecutionProgress',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'deploy_pipeline_artifacts': 'deployPipelineArtifacts',
            'deploy_pipeline_environments': 'deployPipelineEnvironments',
            'deployment_type': 'deploymentType',
            'id': 'id',
            'display_name': 'displayName',
            'project_id': 'projectId',
            'deploy_pipeline_id': 'deployPipelineId',
            'compartment_id': 'compartmentId',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'deployment_arguments': 'deploymentArguments',
            'deploy_artifact_override_arguments': 'deployArtifactOverrideArguments',
            'deployment_execution_progress': 'deploymentExecutionProgress',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._deploy_pipeline_artifacts = None
        self._deploy_pipeline_environments = None
        self._deployment_type = None
        self._id = None
        self._display_name = None
        self._project_id = None
        self._deploy_pipeline_id = None
        self._compartment_id = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._deployment_arguments = None
        self._deploy_artifact_override_arguments = None
        self._deployment_execution_progress = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None
        self._deployment_type = 'PIPELINE_DEPLOYMENT'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateResourceDetails(object):
    """
    Details about updates to the resource.

    **Caution:** Avoid using any confidential information when you supply string values using the API.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateResourceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param item:
            The value to assign to the item property of this UpdateResourceDetails.
        :type item: oci.cims.models.UpdateItemDetails

        """
        self.swagger_types = {
            'item': 'UpdateItemDetails'
        }

        self.attribute_map = {
            'item': 'item'
        }

        self._item = None

    @property
    def item(self):
        """
        Gets the item of this UpdateResourceDetails.

        :return: The item of this UpdateResourceDetails.
        :rtype: oci.cims.models.UpdateItemDetails
        """
        return self._item

    @item.setter
    def item(self, item):
        """
        Sets the item of this UpdateResourceDetails.

        :param item: The item of this UpdateResourceDetails.
        :type: oci.cims.models.UpdateItemDetails
        """
        self._item = item

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
